@@ -4,26 +4,26 @@ Created on Wed Oct 30 11:29:58 2019
 
 @author: yoelr
 """
-from ._chemical import Chemical
-from ._chemicals import Chemicals, CompiledChemicals
-from ._thermo import Thermo
-from ._stream import Stream
-from ._multi_stream import MultiStream
-from ._settings import settings
-from ._thermal_condition import ThermalCondition
-from .base import functor
-
 from . import (base,
                utils,
                properties,
-               indexer,
-               equilibrium,
                exceptions,
                functional,
+)
+from ._chemical import Chemical
+from ._chemicals import Chemicals, CompiledChemicals
+from ._thermal_condition import ThermalCondition
+from . import mixture
+from ._thermo import Thermo
+from ._settings import settings
+from . import (indexer,
                reaction,
-               mixture)
-
-speed_up = utils.speed_up
+               equilibrium
+)
+from ._stream import Stream
+from ._multi_stream import MultiStream
+from .base import functor
+from flexsolve import speed_up
 
 __all__ = ('Chemical', 'Chemicals', 'CompiledChemicals', 'Thermo', 'indexer',
            'Stream', 'MultiStream', 'ThermalCondition', 'mixture',
