@@ -865,7 +865,7 @@ class GroupCounts(dict):
         cls.ids_by_group_name = {subgroup.group: key
                                  for key, subgroup in subgroups_by_id.items()}
     
-    def set_group_counts_by_name(self, group_counts):
+    def set_group_counts_by_name(self, group_counts: dict):
         self.clear()
         ids_by_group_name = self.ids_by_group_name
         for name, count in group_counts.items():
@@ -891,6 +891,7 @@ class GroupCounts(dict):
         group_counts = self._show_group_counts()
         return f"<{type(self).__name__}: {group_counts}>"
 
+
 class UNIFACGroupCounts(GroupCounts):
     __slots__ = ()
     subgroups_by_id = UFSG
